from fastapi import status
from fastapi_utils.cbv import cbv
from fastapi.responses import JSONResponse
from fastapi_utils.inferring_router import InferringRouter
import _version

# Const for static app status response
RESPONSE_OK = {"status": "ok"}

base_router = InferringRouter()


@cbv(base_router)
class BaseHandler:
    @base_router.get("/public/status")
    def healthcheck(self) -> dict:
        """function to check the health of the server

        Returns:
            response (JSONResponse): json response
        """

        return JSONResponse(status_code=status.HTTP_200_OK, content=RESPONSE_OK)

    @base_router.get("/version")
    def version_check(self) -> dict:
        """method for handling a request to get version

        Returns:
            response (JSONResponse): json response
        """
        version = _version.__version__

        return JSONResponse(content={"version": version})
