from fastapi_utils.cbv import cbv
from fastapi_utils.inferring_router import InferringRouter

from models.stal import StalLogoutModel, StalUserModel, StalRemoteAppModel
from services.stal import StalService

stal_router = InferringRouter()


@cbv(stal_router)
class StalHandler:
    def __init__(self) -> None:
        self.stal = StalService()

    @stal_router.get("/stal/versions")
    def version(self):
        """
        Method for gets STAL version.
        """
        return self.stal.version()

    @stal_router.get("/rds/test")  # FIXME: "/stal/test"
    def status(self):
        """
        Method for gets STAL status.
        """
        return self.stal.status()

    @stal_router.get("/rds/sessions")  # FIXME: "/stal/sessions"
    def sessions(self):
        """
        Method for gets a list of running sessions.
        """
        return self.stal.sessions()

    @stal_router.post("/rds/login")  # FIXME: "/stal/login"
    def login_user(self, user: StalUserModel):
        """
        Method for authentication user
        """
        return self.stal.login_user(user)

    @stal_router.post("/stal/disconnect_")
    def disconnect_user(self, user: StalLogoutModel):
        """
        Method for disconnect user
        """
        return self.stal.disconnect_user(user)

    @stal_router.post("/rds/disconnect")  # FIXME: "/stal/shutdown"
    def shutdown_user(self, user: StalLogoutModel):
        """
        Method for shutdown user session
        """
        return self.stal.shutdown_user(user)

    @stal_router.post("/rds/testconnect")  # FIXME: "/stal/testconnect"
    def test_connect(self, user: StalUserModel):
        """
        Method for check user in STAL
        """
        return self.stal.test_connect(user)

    @stal_router.post("/stal/sessionrequest")
    def session_request(self, user: StalUserModel):
        """
        Method for creating user session in STAL
        """
        return self.stal.session_request(user)

    @stal_router.post('/stal/programrequest')
    def program_request(self, data: StalRemoteAppModel):
        """
        Method for creating user session in STAL in single program mode
        """
        return self.stal.program_request(data)

    @stal_router.get("/stal/apps")
    def stal_apps(self):
        """
        Method for to get published remote apps.
        """
        return self.stal.get_remote_apps()
