import os

from environment.checks import PlatformEnvironment


# Для изменения уровня логирования через конфиг достаточно поментяь значение переменной LOG_LEVEL
# Допустимые значения: NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL
LOG_LEVEL = "INFO"
SSA_LOG_LEVEL = os.getenv("SSA_LOG_LEVEL", LOG_LEVEL)

if PlatformEnvironment.is_linux():
    LOG_FILE_PATH = "/var/log/termidesk/session-agent.log"

if PlatformEnvironment.is_windows():
    PROGRAM_DATA = os.path.expandvars(r"%PROGRAMDATA%")
    LOG_FILE_PATH = os.path.join(
        PROGRAM_DATA, "UVEON", "Termidesk Session Agent", "log", "session-agent.log"
    )


LOGGING_CONFIG = {
    "version": 1,
    "disable_existing_loggers": False,
    "formatters": {
        "default": {
            "()": "uvicorn.logging.DefaultFormatter",
            "fmt": "%(levelprefix)s %(message)s",
            "use_colors": None,
        },
        "access": {
            "()": "uvicorn.logging.AccessFormatter",
            "fmt": '%(levelprefix)s %(client_addr)s - "%(request_line)s" %(status_code)s',
        },
        "file": {
            "format": "%(asctime)s.%(msecs)03d %(levelname)-6s %(name)s - %(message)s",
        },
    },
    "handlers": {
        "default": {
            "formatter": "default",
            "class": "logging.StreamHandler",
            "stream": "ext://sys.stderr",
        },
        "access": {
            "formatter": "access",
            "class": "logging.StreamHandler",
            "stream": "ext://sys.stdout",
        },
        "file": {
            "formatter": "file",
            "class": "logging.FileHandler",
            "filename": LOG_FILE_PATH,
        },
    },
    "loggers": {
        "uvicorn": {
            "handlers": ["default", "file"],
            "level": SSA_LOG_LEVEL,
            "propagate": False,
        },
        "uvicorn.error": {"level": SSA_LOG_LEVEL},
        "uvicorn.access": {
            "handlers": ["access", "file"],
            "level": SSA_LOG_LEVEL,
            "propagate": False,
        },
    },
    "root": {
        "handlers": ["default", "file"],
        "level": SSA_LOG_LEVEL,
        "propagate": False,
    },
}
